@@ -9,6 +9,10 @@ def sigmoid(x):
     return 1/(1+np.exp(-x))
 
 
+def abslog(x):
+    return np.log1p(np.abs(x))
+
+
 def _make_random_state(random):
 
     if random is None:
